import ReactExports from 'react';
import { createStore } from 'zustand/vanilla';

const { useDebugValue, useMemo, useSyncExternalStore } = ReactExports;
const identity = (arg) => arg;
const useMemoSelector = (getState, selector) => useMemo(() => {
  let prev;
  return () => {
    const state = getState();
    if (!prev || !Object.is(prev[0], state)) {
      prev = [state, selector(state)];
    }
    return prev[1];
  };
}, [getState, selector]);
function useStore(api, selector = identity) {
  const slice = useSyncExternalStore(
    api.subscribe,
    useMemoSelector(api.getState, selector),
    useMemoSelector(api.getInitialState, selector)
  );
  useDebugValue(slice);
  return slice;
}
const createImpl = (createState) => {
  const api = createStore(createState);
  const useBoundStore = (selector) => useStore(api, selector);
  Object.assign(useBoundStore, api);
  return useBoundStore;
};
const create = (createState) => createState ? createImpl(createState) : createImpl;

export { create, useStore };
